This class contains bivariate circular-linear copulas, generated from
linear-linear bivariate 'Copula' objects of the package
'copula', by taking the arithmetic mean of the original copula and
the 90 deg rotated copula. This results in copulas that are periodic in the
circular dimension, u, and symmetric with respect to \(u=0.5\), i.e. positive
and negative angles.
namecharacter string holding the name of the copula.
parameters
param.names
param.lowbnd
param.upbnd
orig.coplinear-linear 2-dimensional 'Copula'
object of the package 'copula'.
shiftlogical value indicating whether the (u-periodic) copula should be shifted by 0.5 in u direction.
Objects are created by cyl_rot_combine().
Class 'cyl_rot_combine' extends class 'Copula'.
Nelsen2006cylcop
Hodelapplcylcop
Hodelmethodcylcop